@@ -29,7 +29,6 @@
  *   and things like ncurses libmenu are not worth the storage overhead.
  *
  */
-
 /* Why is this needed? Segfaults without it */
 #include <netinet/in.h>
 
@@ -41,6 +40,8 @@
 #include "gui.h"
 #include "pass.h"
 #include "logging.h"
+#include "version.h"
+
 
 #define NWIPE_GUI_PANE        8
 
@@ -229,7 +230,7 @@ void nwipe_gui_init( void )
 	wclear( header_window );
 
 	/* Print the product banner. */
-	nwipe_gui_title( header_window, nwipe_options.banner );
+    nwipe_gui_title( header_window, banner );
 
 	/* Create the footer window. */
 	footer_window = newwin( NWIPE_GUI_FOOTER_H, NWIPE_GUI_FOOTER_W, NWIPE_GUI_FOOTER_Y, NWIPE_GUI_FOOTER_X );
@@ -446,40 +447,40 @@ void nwipe_gui_select( int count, nwipe_context_t** c )
 			{
 				case NWIPE_SELECT_TRUE:
 
-					wprintw( main_window, " [wipe] %i. %s - %s %s (%lld bytes)", (i + offset + 1),
+					wprintw( main_window, " [wipe] %i. %s - %s %s (%s)", (i + offset + 1),
 										c[i+offset]->device_name,
 										c[i+offset]->label,
 										c[i+offset]->identity.serial_no,
-										c[i+offset]->device_size );
+										c[i+offset]->device_size_text );
 					break;
 
 				case NWIPE_SELECT_FALSE:
 					/* Print an element that is not selected. */
-					wprintw( main_window, " [    ] %i. %s - %s %s (%lld bytes)", (i + offset +1),
+					wprintw( main_window, " [    ] %i. %s - %s %s (%s)", (i + offset +1),
 										c[i+offset]->device_name,
 										c[i+offset]->label,
 										c[i+offset]->identity.serial_no,
-										c[i+offset]->device_size );
+										c[i+offset]->device_size_text );
 					break;
 
 				case NWIPE_SELECT_TRUE_PARENT:
 
 					/* This element will be wiped when its parent is wiped. */
-					wprintw( main_window, " [****] %i. %s - %s %s (%lld bytes)", (i + offset +1),
+					wprintw( main_window, " [****] %i. %s - %s %s (%s)", (i + offset +1),
 										c[i+offset]->device_name,
 										c[i+offset]->label,
 										c[i+offset]->identity.serial_no,
-										c[i+offset]->device_size );
+										c[i+offset]->device_size_text );
 					break;
 
 				case NWIPE_SELECT_FALSE_CHILD:
 
 					/* We can't wipe this element because it has a child that is being wiped. */
-					wprintw( main_window, " [----] %i. %s - %s %s (%lld bytes)", (i + offset +1),
+					wprintw( main_window, " [----] %i. %s - %s %s (%s)", (i + offset +1),
 										c[i+offset]->device_name,
 										c[i+offset]->label,
 										c[i+offset]->identity.serial_no,
-										c[i+offset]->device_size );
+										c[i+offset]->device_size_text );
 					break;
 
 				case NWIPE_SELECT_DISABLED:
@@ -1867,13 +1868,13 @@ void *nwipe_gui_status( void *ptr )
 
 				if( c[i]->sync_status   ) { wprintw( main_window, "[syncing] "   ); }
 
-				     if( c[i]->throughput >= INT64_C( 1000000000000000 ) )
+				     if( c[i]->throughput >= INT64_C( 1000000000000    ) )
 					    { wprintw( main_window, "[%llu TB/s] ", c[i]->throughput / INT64_C( 1000000000000 ) ); }
-				else if( c[i]->throughput >= INT64_C( 1000000000000    ) )
-				       { wprintw( main_window, "[%llu GB/s] ", c[i]->throughput / INT64_C( 1000000000    ) ); }
 				else if( c[i]->throughput >= INT64_C( 1000000000       ) )
-				       { wprintw( main_window, "[%llu MB/s] ", c[i]->throughput / INT64_C( 1000000       ) ); }
+				       { wprintw( main_window, "[%llu GB/s] ", c[i]->throughput / INT64_C( 1000000000    ) ); }
 				else if( c[i]->throughput >= INT64_C( 1000000          ) )
+				       { wprintw( main_window, "[%llu MB/s] ", c[i]->throughput / INT64_C( 1000000       ) ); }
+				else if( c[i]->throughput >= INT64_C( 1000             ) )
 				       { wprintw( main_window, "[%llu KB/s] ", c[i]->throughput / INT64_C( 1000          ) ); }
 				else
 				       { wprintw( main_window, "[%llu B/s] ",  c[i]->throughput / INT64_C( 1             ) ); }
@@ -1908,13 +1909,13 @@ void *nwipe_gui_status( void *ptr )
 
 
 			u64 nwipe_throughput = nwipe_misc_thread_data->throughput;
-			     if( nwipe_throughput >= INT64_C( 1000000000000000 ) )
+			     if( nwipe_throughput >= INT64_C( 1000000000000    ) )
 				    { nwipe_throughput /= INT64_C( 1000000000000    ); nwipe_format = nwipe_tera; }
-			else if( nwipe_throughput >= INT64_C( 1000000000000    ) )
-			       { nwipe_throughput /= INT64_C( 1000000000       ); nwipe_format = nwipe_giga; }
 			else if( nwipe_throughput >= INT64_C( 1000000000       ) )
-			       { nwipe_throughput /= INT64_C( 1000000          ); nwipe_format = nwipe_mega; }
+			       { nwipe_throughput /= INT64_C( 1000000000       ); nwipe_format = nwipe_giga; }
 			else if( nwipe_throughput >= INT64_C( 1000000          ) )
+			       { nwipe_throughput /= INT64_C( 1000000          ); nwipe_format = nwipe_mega; }
+			else if( nwipe_throughput >= INT64_C( 1000             ) )
 			       { nwipe_throughput /= INT64_C( 1000             ); nwipe_format = nwipe_kilo; }
 			else
 			       { nwipe_throughput /= INT64_C( 1                ); nwipe_format = nwipe_unit; }
