@@ -69,9 +69,6 @@ int main( int argc, char** argv )
         /* Initialised and populated in device scan.     */
         nwipe_context_t **c1 = 0;
 
-        /* The array of pointers to contexts that will actually be wiped. */
-        nwipe_context_t **c2 = (nwipe_context_t **)malloc(nwipe_enumerated * sizeof(nwipe_context_t *));
-
         /* Parse command line options. */
         nwipe_optind = nwipe_options_parse( argc, argv );
 
@@ -95,7 +92,6 @@ int main( int argc, char** argv )
 
         else
         {
-
                 argv += nwipe_optind;
                 argc -= nwipe_optind;
 
@@ -108,6 +104,9 @@ int main( int argc, char** argv )
         }
 
 
+        /* The array of pointers to contexts that will actually be wiped. */
+        nwipe_context_t **c2 = (nwipe_context_t **)malloc(nwipe_enumerated * sizeof(nwipe_context_t *));
+
         /* Open the entropy source. */
         nwipe_entropy = open( NWIPE_KNOB_ENTROPY, O_RDONLY );
 
@@ -147,12 +146,14 @@ int main( int argc, char** argv )
                 nwipe_misc_thread_data.gui_thread = &nwipe_gui_thread;
         nwipe_thread_data_ptr.nwipe_misc_thread_data = &nwipe_misc_thread_data;
 
-        pthread_attr_t pthread_attr;
-        pthread_attr_init(&pthread_attr);
-        pthread_attr_setdetachstate(&pthread_attr, PTHREAD_CREATE_DETACHED);
-
-        pthread_create( &nwipe_sigint_thread, &pthread_attr, signal_hand, &nwipe_thread_data_ptr);
+	if( !nwipe_options.nosignals )
+	{
+	  pthread_attr_t pthread_attr;
+	  pthread_attr_init(&pthread_attr);
+	  pthread_attr_setdetachstate(&pthread_attr, PTHREAD_CREATE_DETACHED);
 
+	  pthread_create( &nwipe_sigint_thread, &pthread_attr, signal_hand, &nwipe_thread_data_ptr);
+	}
 
         /* A context struct for each device has already been created. */
         /* Now set specific nwipe options */
@@ -354,7 +355,7 @@ int main( int argc, char** argv )
                 }
 
 
-                if( c2[i]->device_size == (loff_t)-1 )
+                if( c2[i]->device_size == (long long)-1 )
                 {
                         /* We cannot determine the size of this device. */
                         nwipe_perror( errno, __FUNCTION__, "lseek" );
@@ -367,7 +368,7 @@ int main( int argc, char** argv )
                         /* Reset the file pointer. */
                         r = lseek( c2[i]->device_fd, 0, SEEK_SET );
         
-                        if( r == (loff_t)-1 )
+                        if( r == (off64_t)-1 )
                         {
                                 nwipe_perror( errno, __FUNCTION__, "lseek" );
                                 nwipe_log( NWIPE_LOG_ERROR, "Unable to reset the '%s' file offset.", c2[i]->device_name );
@@ -523,7 +524,7 @@ void *signal_hand(void *ptr)
 
                                         if ( c[i]->thread )
                                         {
-                                                char *status;
+                                                char *status = "";
                                                 switch( c[i]->pass_type )
                                                 {
                                                         case NWIPE_PASS_FINAL_BLANK:
