@@ -31,6 +31,11 @@
 #define _FILE_OFFSET_BITS 64
 #endif
 
+/* workaround for Fedora */
+#ifndef off64_t
+# define off64_t off_t
+#endif
+
 /* Busybox headers. */
 #ifdef BB_VER
 #include "busybox.h"
@@ -65,12 +70,15 @@ extern int log_current_element;
 extern int log_elements_allocated;
 extern pthread_mutex_t mutex1;
 
-/* Ncurses headers. Assume panel.h is in same place.*/
+/* Ncurses headers. */
 #ifdef NCURSES_IN_SUBDIR
     #include <ncurses/ncurses.h>
-    #include <ncurses/panel.h>
 #else
     #include <ncurses.h>
+#endif
+#ifdef PANEL_IN_SUBDIR
+    #include <ncurses/panel.h>
+#else
     #include <panel.h>
 #endif
 
