@@ -42,9 +42,6 @@ int nwipe_options_parse( int argc, char** argv )
 	extern nwipe_prng_t nwipe_twister;
 	extern nwipe_prng_t nwipe_isaac;
 
-	/* The maximum banner size, including the null. */
-	const int nwipe_banner_size = 81;
-
 	/* The getopt() result holder. */
 	int nwipe_opt;
 
@@ -81,6 +78,9 @@ int nwipe_options_parse( int argc, char** argv )
 		/* Whether to exit after wiping or wait for a keypress. */
 		{ "nowait", no_argument, 0, 0 },
 
+		/* Whether to allow signals to interrupt a wipe. */
+		{ "nosignals", no_argument, 0, 0 },
+
 		/* Whether to exit after wiping or wait for a keypress. */
 		{ "nogui", no_argument, 0, 0 },
 
@@ -97,15 +97,6 @@ int nwipe_options_parse( int argc, char** argv )
 		{ 0, 0, 0, 0 }
 	};
 
-	/* Note that COLS isn't available until ncurses is initialized. */
-	nwipe_options.banner = malloc( nwipe_banner_size );
-
-	/* Set the default product banner. */
-	/* TODO: Add version constant.     */
-	strncpy ( nwipe_options.banner, program_name, nwipe_banner_size);
-	strncat ( nwipe_options.banner, " ", nwipe_banner_size - strlen (nwipe_options.banner) - 1);
-	strncat ( nwipe_options.banner, version_string, nwipe_banner_size - strlen (nwipe_options.banner) - 1);
-	strncat ( nwipe_options.banner, " (based on DBAN's dwipe - Darik's Wipe)", nwipe_banner_size - strlen (nwipe_options.banner) - 1);
 
 	/* Set default options. */
 	nwipe_options.autonuke = 0;
@@ -114,6 +105,7 @@ int nwipe_options_parse( int argc, char** argv )
 	nwipe_options.rounds   = 1;
 	nwipe_options.noblank  = 0;
 	nwipe_options.nowait   = 0;
+	nwipe_options.nosignals= 0;
 	nwipe_options.nogui    = 0;
 	nwipe_options.sync     = 0;
 	nwipe_options.verify   = NWIPE_VERIFY_LAST;
@@ -151,6 +143,12 @@ int nwipe_options_parse( int argc, char** argv )
 					break;
 				}
 
+				if( strcmp( nwipe_options_long[i].name, "nosignals" ) == 0 )
+				{
+					nwipe_options.nosignals = 1;
+					break;
+				}
+
 				if( strcmp( nwipe_options_long[i].name, "nogui" ) == 0 )
 				{
 					nwipe_options.nogui = 1;
@@ -276,7 +274,7 @@ int nwipe_options_parse( int argc, char** argv )
 				    || nwipe_options.rounds < 1
 				  )
 				{
-					fprintf( stderr, "Error: The rounds argument must be a postive integer.\n" );
+					fprintf( stderr, "Error: The rounds argument must be a positive integer.\n" );
 					exit( EINVAL );
 				}
 
@@ -332,12 +330,17 @@ void nwipe_options_log( void )
 		nwipe_log( NWIPE_LOG_NOTICE, "  do not wait for a key before exiting" );
 	}
 
+	if( nwipe_options.nosignals )
+	{
+		nwipe_log( NWIPE_LOG_NOTICE, "  do not allow signals to interrupt a wipe" );
+	}
+
 	if( nwipe_options.nogui )
 	{
 		nwipe_log( NWIPE_LOG_NOTICE, "  do not show GUI interface" );
 	}
 
-	nwipe_log( NWIPE_LOG_NOTICE, "  banner   = %s", nwipe_options.banner );
+	nwipe_log( NWIPE_LOG_NOTICE, "  banner   = %s", banner );
 	nwipe_log( NWIPE_LOG_NOTICE, "  method   = %s", nwipe_method_label( nwipe_options.method ) );
 	nwipe_log( NWIPE_LOG_NOTICE, "  rounds   = %i", nwipe_options.rounds );
 	nwipe_log( NWIPE_LOG_NOTICE, "  sync     = %i", nwipe_options.sync );
@@ -394,6 +397,7 @@ display_help()
   puts("  -r, --rounds=NUM        Number of times to wipe the device using the selected method (default: 1)" );
   puts("      --noblank           Do not blank disk after wipe (default is to complete a final blank pass)" );
   puts("      --nowait            Do not wait for a key before exiting (default is to wait)" );
+  puts("      --nosignals         Do not allow signals to interrupt a wipe (default is to allow)" );
   puts("      --nogui             Do not show the GUI interface. Automatically invokes the nowait option" );
   puts("                          Must be used with --autonuke option. Send SIGUSR1 to log current stats");
   puts("");
